% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot_annual_normal_days_year.R
\name{plot_annual_normal_days_year}
\alias{plot_annual_normal_days_year}
\title{Plot days above normal, below normal and normal for a specific year}
\usage{
plot_annual_normal_days_year(
  data,
  dates = Date,
  values = Value,
  groups = STATION_NUMBER,
  station_number,
  normal_percentiles = c(25, 75),
  year_to_plot = NA,
  roll_days = 1,
  roll_align = "right",
  water_year_start = 1,
  start_year,
  end_year,
  exclude_years,
  months = 1:12,
  log_discharge = TRUE,
  log_ticks = FALSE,
  include_title = FALSE,
  plot_flow_line = TRUE,
  plot_normal_percentiles = TRUE
)
}
\arguments{
\item{data}{Data frame of daily data that contains columns of dates, flow values, and (optional) groups (e.g. station numbers).
Leave blank or set to \code{NULL} if using \code{station_number} argument.}

\item{dates}{Name of column in \code{data} that contains dates formatted YYYY-MM-DD. Only required if dates column name is not 
'Date' (default). Leave blank or set to \code{NULL} if using \code{station_number} argument.}

\item{values}{Name of column in \code{data} that contains numeric flow values, in units of cubic metres per second.
Only required if values column name is not 'Value' (default). Leave blank if using \code{station_number} argument.}

\item{groups}{Name of column in \code{data} that contains unique identifiers for different data sets, if applicable. Only required 
if groups column name is not 'STATION_NUMBER'. Function will automatically group by a column named 'STATION_NUMBER' if 
present. Remove the 'STATION_NUMBER' column beforehand to remove this grouping. Leave blank if using \code{station_number} 
argument.}

\item{station_number}{Character string vector of seven digit Water Survey of Canada station numbers (e.g. \code{"08NM116"}) of
which to extract daily streamflow data from a HYDAT database. Requires \code{tidyhydat} package and a HYDAT database.
Leave blank if using \code{data} argument.}

\item{normal_percentiles}{Numeric vector of two values, lower and upper percentiles, respectively indicating the limits of the 
normal range. Default \code{c(25,75)}.}

\item{year_to_plot}{Numeric value indicating the year/water year to plot flow data with normal category colours. Default \code{NA}.}

\item{roll_days}{Numeric value of the number of days to apply a rolling mean. Default \code{1}.}

\item{roll_align}{Character string identifying the direction of the rolling mean from the specified date, either by the first 
(\code{'left'}), last (\code{'right'}), or middle (\code{'center'}) day of the rolling n-day group of observations. 
Default \code{'right'}.}

\item{water_year_start}{Numeric value indicating the month (\code{1} through \code{12}) of the start of water year for
analysis. Default \code{1}.}

\item{start_year}{Numeric value of the first year to consider for analysis. Leave blank or set well before start date (i.e.
\code{1800}) to use from the first year of the source data.}

\item{end_year}{Numeric value of the last year to consider for analysis. Leave blank or set well after end date (i.e.
\code{2100}) to use up to the last year of the source data.}

\item{exclude_years}{Numeric vector of years to exclude from analysis. Leave blank or set to \code{NULL} to include all years.}

\item{months}{Numeric vector of months to include in analysis. For example, \code{3} for March, \code{6:8} for Jun-Aug or 
\code{c(10:12,1)} for first four months (Oct-Jan) when \code{water_year_start = 10} (Oct). Default summarizes all 
months (\code{1:12}).}

\item{log_discharge}{Logical value to indicate plotting the discharge axis (Y-axis) on a logarithmic scale. Default \code{FALSE}.}

\item{log_ticks}{Logical value to indicate plotting logarithmic scale ticks when \code{log_discharge = TRUE}. Ticks will not
appear when \code{log_discharge = FALSE}. Default to \code{TRUE} when \code{log_discharge = TRUE}.}

\item{include_title}{Logical value to indicate adding the group/station number to the plot, if provided. Default \code{FALSE}.}

\item{plot_flow_line}{Logical value indicating whether to connect flow data coloured points with lines. Default \code{TRUE}.}

\item{plot_normal_percentiles}{Logical value indicating whether to plot the normal percentiles ribbon. Default \code{TRUE}.}
}
\value{
A list of ggplot2 objects with the following for each station provided:
  \item{Annual_Normal_Days_Year}{a plot that contains the above, below, and normal colour daily flow points}
}
\description{
Plots an annual hydrograph for a specific year with daily flow values coloured by whether the daily values are normal,
   above normal, or below normal, overlaying the normals range. The normal range is typically between 25 and 75th percentiles for
   each day of the year. Upper and lower-range percentiles are calculated for each day of the year of from all years, and then each 
   daily flow value for each year is compared. Normals calculated from only years of complete data, although incomplete years can be 
   plotted. Shows the annual values for a specific year from the counts from the \code{plot_annual_normal_days()} function. 
   Returns a list of plots.
}
\examples{
# Run if HYDAT database has been downloaded (using tidyhydat::download_hydat())
if (file.exists(tidyhydat::hy_downloaded_db())) {

# Plot the year 2000 using a data frame and data argument with defaults
flow_data <- tidyhydat::hy_daily_flows(station_number = "08NM116")
plot_annual_normal_days_year(data = flow_data,
                                year_to_plot = 2000)
                  
# Plot the year 2000 using the station_number argument
plot_annual_normal_days_year(station_number = "08NM116",
                                year_to_plot = 2000)
 
# Plot the year 2000 and change the normal percentiles range          
plot_annual_normal_days_year(station_number = "08NM116",
                                normal_percentiles = c(20,80),
                                year_to_plot = 2000)
                 
}
}
\seealso{
\code{\link{calc_annual_normal_days}}

\code{\link{plot_annual_normal_days}}
}
